from email.policy import default
from nivir.main import Nivir
initTextWelcome = """
------------ NIVIR - GAME ENGINE ---------------
Welcome to NivirGL!
This is a simple game engine made with OpenGL and Glut!
So you can talk with the programmer in Discord:
-   Rinka<3#8908
------------------------
If u wanna learn more about Rinka so you can enter here: https://instabio.cc/rinkadumb
"""
print(initTextWelcome)


from PyQt6.QtWidgets import *
from PyQt6.QtCore import *
from PyQt6.QtGui import *
from OpenGL.GL import *
from OpenGL.GLU import *
import sys

class Nivir:
    def __init__(
        self,
        title: str = "Nivir",
        width: int = 800,
        height: int = 600,
        bgcolor = 'black'
    ) -> None:
        self.title = title
        self.width = width
        self.height = height
        self.bgcolor =  bgcolor
        self.shouldShow = True
        self.app = QApplication(sys.argv)
        self.window = QMainWindow()
        self.window.setWindowTitle(self.title)
        self.window.setFixedSize(QSize(self.width, self.height))
        self.window.setStyleSheet(f"background-color: {self.bgcolor};")
        self.window.show()

    def custom(
        self,
        title:str = "New Custom Title",
        width:int = 800,
        height:int = 600,
        bgcolor = 'black'
    ):
        self.title = title
        self.width = width
        self.height = height
        self.bgcolor = bgcolor
        
        self.window.setWindowTitle(self.title)
        self.window.setFixedSize(QSize(self.width, self.height))
        self.window.setStyleSheet(f"background-color: {self.bgcolor};")

    def run(self):
        self.app.exec()

if __name__ == '__main__':
    NIVIR_TEST_APP = Nivir()

    NIVIR_TEST_APP.run()


from setuptools import setup

readme = open("./README.md", "r")

setup(
    name = "nivir",
    packages=['nivir'],
    version='0.2',
    description="Nivir is a simple game engine",
    long_description=readme.read(),
    long_description_content_type='text/markdown',
    author = "Rinka",
    author_email="labatanightcore@gmail.com",
    license='MIT',
    include_package_data=True
)